@@ -1285,6 +1285,7 @@ sub get_name {
       : "current_date + c.terms";
 
     $form->{"$form->{vc}_id"} *= 1;
+    
 
     # get customer/vendor
     my $query = qq|
@@ -1314,6 +1315,7 @@ sub get_name {
             delete $ref->{$_};
         }
     }
+    delete $ref->{duedate} if $form->{duedate};
 
     for ( keys %$ref ) { $form->{$_} = $ref->{$_} }
     $sth->finish;
@@ -1349,39 +1351,23 @@ sub get_name {
 
     $form->{creditremaining} = $form->{creditlimit};
     $query = qq|
-		SELECT SUM(amount - paid)
+                SELECT sum(used) FROM (
+		SELECT SUM(amount - paid) as used
 		  FROM $arap
-		 WHERE id = ?|;
+		 WHERE entity_credit_account = ?
+                 UNION 
+                SELECT sum(o.amount * coalesce(e.$buysell, 1)) as used
+                  FROM oe o
+             LEFT JOIN exchangerate e ON o.transdate = e.transdate
+                 WHERE not closed and oe_class_id in (1, 2)
+                       and entity_credit_account = ?) s|;
 
     $sth = $dbh->prepare($query);
-    $sth->execute( $form->{"$form->{vc}_id"} )
+    $sth->execute( $form->{"$form->{vc}_id"}, $form->{"$form->{vc}_id"})
       || $form->dberror($query);
     my ($credit_rem) = $sth->fetchrow_array;
     ( $form->{creditremaining} ) -= Math::BigFloat->new($credit_rem);
 
-    $sth->finish;
-    if ( $form->{vc} ne "customer" ) {
-        $form->{vc} = 'vendor';
-    }
-
-    $query = qq|
-		SELECT o.amount, (SELECT e.$buysell FROM exchangerate e
-		                   WHERE e.curr = o.curr
-		                         AND e.transdate = o.transdate)
-		  FROM oe o
-		 WHERE o.entity_id = ?
-		       AND o.quotation = '0' AND o.closed = '0'|;
-
-    $sth = $dbh->prepare($query);
-    $sth->execute( $form->{"$form->{vc}_id"} ) || $form->dberror($query);
-
-    while ( my @ref = $sth->fetchrow_array ) {
-        $form->db_parse_numeric(sth => $sth, arrayref => \@ref);
-        my ($amount, $exch) = @ref;
-        $exch = 1 unless $exch;
-        $form->{creditremaining} -= $amount * $exch;
-    }
-
     $sth->finish;
 
     # get shipto if we did not converted an order or invoice
