@@ -202,7 +202,7 @@ sub get_part {
         $query = qq|
 			  SELECT v.id, e.name, pv.partnumber,
 			         pv.lastcost, pv.leadtime, 
-			         pv.curr AS vendorcurr
+			         pv.curr AS vendorcurr, v.meta_number
 			    FROM partsvendor pv
 			    JOIN entity_credit_account v 
                                  ON (v.id = pv.credit_id)
@@ -226,12 +226,12 @@ sub get_part {
 			   SELECT pc.pricebreak, pc.sellprice AS customerprice,
 			          pc.curr AS customercurr, pc.validfrom, 
 			          pc.validto, e.name, c.id AS cid, 
-			          g.pricegroup, g.id AS gid
+			          g.pricegroup, g.id AS gid, c.meta_number
 			     FROM partscustomer pc
 			LEFT JOIN entity_credit_account c 
                                   ON (c.id = pc.credit_id)
 			LEFT JOIN pricegroup g ON (g.id = pc.pricegroup_id)
-                 JOIN entity e ON (e.id = c.entity_id)
+                        LEFT JOIN entity e ON (e.id = c.entity_id)
 			    WHERE pc.parts_id = ?
 			 ORDER BY e.name, g.pricegroup, pc.pricebreak|;
         $sth = $dbh->prepare($query);
@@ -590,6 +590,7 @@ sub save {
 
             ( $null, $customer_id ) = split /--/, $form->{"customer_$i"};
             $customer_id *= 1;
+            $customer_id ||= undef; # 0 id is invalid anyway.
 
             ( $null, $pricegroup_id ) = split /--/, $form->{"pricegroup_$i"};
 
