@@ -343,6 +343,7 @@ sub invoice_details {
             # add number, description and qty to $form->{number}...
             push( @{ $form->{runningnumber} }, $runningnumber++ );
             push( @{ $form->{number} },        $form->{"partnumber_$i"} );
+            push( @{ $form->{image} },        $form->{"image_$i"} );
             push( @{ $form->{sku} },           $form->{"sku_$i"} );
             push( @{ $form->{serialnumber} },  $form->{"serialnumber_$i"} );
 
@@ -2144,7 +2145,8 @@ sub retrieve_invoice {
 			          p.partnumber AS sku, p.listprice, p.lastcost,
 			          p.weight, p.onhand, p.inventory_accno_id, 
 			          p.income_accno_id, p.expense_accno_id,
-			          t.description AS partsgrouptranslation
+			          t.description AS partsgrouptranslation, 
+                                  p.image
 			     FROM invoice i
 		             JOIN parts p ON (i.parts_id = p.id)
 			LEFT JOIN project pr ON (i.project_id = pr.id)
