@@ -21,6 +21,7 @@ our $auth = 'DB';
 our $logging = 0;      # No logging on by default
 our $images = getcwd() . '/images'; 
 our $cssdir = 'css/';
+our $fs_cssdir = 'css/';
 
 our $force_username_case = undef; # don't force case
 
@@ -106,7 +107,7 @@ read_config( 'ledgersmb.conf' => %config ) or die;
 for my $var (
     qw(pathsep logging log_level DBI_TRACE check_max_invoices language auth latex
     db_autoupdate force_username_case max_post_size decimal_places cookie_name
-    return_accno no_db_str tempdir cache_templates cssdir)
+    return_accno no_db_str tempdir cache_templates cssdir fs_cssdir)
   )
 {
     ${$var} = $config{''}{$var} if $config{''}{$var};
