@@ -53,7 +53,11 @@ use CGI::Simple::Standard qw(:html);
 use Template;
 use XML::Twig;
 use OpenOffice::OODoc;
+use OpenOffice::OODoc::Styles;
 use LedgerSMB::Template::TTI18N;
+use LedgerSMB::Sysconfig;
+
+$OpenOffice::OODoc::File::WORKING_DIRECTORY = $LedgerSMB::Sysconfig::tempdir;
 
 my $binmode = undef;
 binmode STDOUT, ':bytes';
@@ -63,7 +67,11 @@ binmode STDERR, ':bytes';
 my $ods;
 my $rowcount;
 my $currcol;
+my $maxrows;
+my $maxcols;
 my %celltype;
+my $sheetnum = -1;
+my $sheetname;
 
 # SC: The elements of the style table for regular styles and stack are
 #     arrays where the stack name is the first element and the style
@@ -119,16 +127,20 @@ my @line_width = ('none', '0.018cm solid', '0.035cm solid',
 	);
 
 sub _worksheet_handler {
+        $sheetnum += 1;
 	$rowcount = -1;
 	$currcol = 0;
 	my $rows = $_->{att}->{rows};
 	my $columns = $_->{att}->{columns};
 	$rows ||= 1000;
 	$columns ||= 52;
+        $maxrows = $rows;
+        $maxcols = $columns;
 	my $sheet;
 	if ($_->is_first_child) {
 		$sheet = $ods->getTable(0, $rows, $columns);
 		$ods->renameTable($sheet, $_->{att}->{name});
+                $sheetname = $_->{att}->{name};
 	} else {
 		$sheet = $ods->appendTable($_->{att}->{name}, $rows, $columns);
 	}
@@ -140,7 +152,8 @@ sub _row_handler {
 }
 
 sub _cell_handler {
-	my $cell = $ods->getCell(-1, $rowcount, $currcol);
+        $ods->expandTable($sheetname, $maxrows, $maxcols);
+	my $cell = $ods->getCell($sheetname, $rowcount, $currcol);
 	
 	if (@style_stack and $celltype{$style_stack[0][0]}) {
 		$ods->cellValueType($cell, $celltype{$style_stack[0][0]}[0]);
@@ -152,7 +165,7 @@ sub _cell_handler {
 			$ods->cellValueType($cell, 'float');
 		}
 	}
-	$ods->cellValue($cell, $_->{att}->{text});
+	$ods->cellValue($sheetname, $rowcount, $currcol, $_->{att}->{text});
 	if (@style_stack) {
 		$ods->cellStyle($cell, $style_stack[0][0]);
 	}
@@ -160,7 +173,7 @@ sub _cell_handler {
 }
 
 sub _formula_handler {
-	my $cell = $ods->getCell(-1, $rowcount, $currcol);
+	my $cell = $ods->getCell($sheetnum, $rowcount, $currcol);
 	
 	if (@style_stack and $celltype{$style_stack[0][0]}) {
 		$ods->cellValueType($cell, $celltype{$style_stack[0][0]}[0]);
@@ -762,8 +775,7 @@ sub _format_cleanup_handler {
 
 sub _ods_process {
 	my ($filename, $template) = @_;
-
-	$ods = ooDocument(file => $filename, create => 'spreadsheet');
+	$ods = ooDocument(file => "$filename", create => 'spreadsheet');
 	
 	my $parser = XML::Twig->new(
 		start_tag_handlers => {
