@@ -5,14 +5,14 @@ function init(div_id) {
 		if (e != e * 1){
 			continue;
                 }
-		e = lis.item(e);
+		e = lis[e];
 		if (e.getAttribute('class') == "nav"){
 			e.addEventListener('click', function (e) {
 				for (var a in this.getElementsByTagName('a')){
 					if (a != a * 1){
 						continue;
 					}
-					a = this.getElementsByTagName('a').item(a);
+					a = this.getElementsByTagName('a')[a];
 					var dest = a.getAttribute('href');
 					dest = dest.replace('#', '');
 					select_div(dest);
@@ -31,7 +31,7 @@ function select_div(div_id){
 	var divs = document.getElementsByTagName('div');
 	var i = 0;
 	for (i=0;i<=divs.length;i++){
-		var e = divs.item(i);
+		var e = divs[i];
 		if (!e || !e.getAttribute || !e.getAttribute('class')){
 			continue;
 		}
