@@ -1149,7 +1149,7 @@ sub list_language {
     push @buttons, {
         name => 'action',
         value => 'add_language',
-        text => $locale->text('Add Lanugage'),
+        text => $locale->text('Add Language'),
         type => 'submit',
         class => 'submit',
     };
@@ -2437,7 +2437,6 @@ sub edit_recurring {
 }
 
 sub process_transactions {
-
     # save variables
     my $pt = new Form;
     for ( keys %$form ) { $pt->{$_} = $form->{$_} }
@@ -2458,7 +2457,7 @@ sub process_transactions {
             $id = $pt->{"ndx_$i"};
 
             # process transaction
-            AM->recurring_details( \%myconfig, \%$pt, $id );
+            AM->recurring_details( \%myconfig, $pt, $id );
 
 
             # reset $form
@@ -2536,9 +2535,7 @@ sub process_transactions {
                     # tax accounts
                     $form->all_taxaccounts( \%myconfig, undef,
                         $form->{transdate} );
-                    $form->{transdate} = $form->convert_date(
-                             $pt->{nextdate}, \%myconfig
-                    );
+                    $form->{transdate} = $pt->{nextdate};
                     # calculate duedate
                     $form->{duedate} =
                       $form->add_date( \%myconfig, $form->{transdate},
