@@ -383,7 +383,9 @@ sub form_header {
           . $form->escape( $form->{selectvendor}, 1 ) . qq|">|;
     }
     else {
-        $vendor = qq|<input name=vendor value="$form->{vendor}" size=35>|;
+        $vendor = qq|<input name=vendor value="$form->{vendor}" size=35>
+                 <a href="vendor.pl?action=add" target="new" id="new-contact">[|
+                 .  $locale->text('New') . qq|]</a>|;
     }
 
     $department = qq|
@@ -405,6 +407,7 @@ sub form_header {
 
     print qq|
 <body onLoad="document.forms[0].${focus}.focus()" />
+| . $form->open_status_div . qq|
 
 <form method=post action="$form->{script}">
 |;
@@ -964,7 +967,7 @@ qq|<td align=center><input name="memo_$i" size=11 value="$form->{"memo_$i"}"></t
 
     print qq|
 </form>
-
+| . $form->close_status_div . qq|
 </body>
 </html>
 |;
@@ -1326,8 +1329,7 @@ sub post {
     ( $form->{AP_paid} ) = split /--/, $form->{AP_paid};
 
     if ( IR->post_invoice( \%myconfig, \%$form ) ) {
-        $form->redirect(
-            $locale->text( 'Invoice [_1] posted!', $form->{invnumber} ) );
+        edit();
     }
     else {
         $form->error( $locale->text('Cannot post invoice!') );
