@@ -34,13 +34,13 @@ sub redirect {
     if ( !$script ) {    # http redirect to login.pl if called w/no args
         print "Location: login.pl\n";
         print "Content-type: text/html\n\n";
-        exit;
+        return;
     }
-    if (first { $_ eq $script } @{LedgerSMB::Sysconfig::newscripts}){
+    #if (first { $_ eq $script } @{LedgerSMB::Sysconfig::newscripts}){
         print "Location: $form->{callback}\n";
         print "Content-type: text/html\n\n";
-        exit;
-    }
+        return;
+    #}
     $form->error(
         $locale->text(
             __FILE__ . ':' . __LINE__ . ':' . $script . ':' . "Invalid Redirect"
