@@ -48,7 +48,6 @@
 
 use LedgerSMB::Sysconfig;
 use Digest::MD5;
-use Error qw(:try);
 use LedgerSMB::App_State;
 
 $| = 1;
@@ -61,6 +60,7 @@ use LedgerSMB::Locale;
 use LedgerSMB::Auth;
 use LedgerSMB::CancelFurtherProcessing;
 use LedgerSMB::App_State;
+use Error qw(:try);
 use Data::Dumper;
 
 our $logger=Log::Log4perl->get_logger('old-handler-chain');#make logger available to other old programs
@@ -71,17 +71,25 @@ require "common.pl";
 eval { require "custom.pl"; };
 
 $form = new Form;
-
 # name of this script
-$0 =~ tr/\\/\//;
-$pos = rindex $0, '/';
-$script = substr( $0, $pos + 1 );
+my $script;
+if ($ENV{GATEWAY_INTERFACE} =~ /^CGI/){
+    $uri = $ENV{REQUEST_URI};
+    $uri =~ s/\?.*//;
+    $ENV{SCRIPT_NAME} = $uri;
+    $ENV{SCRIPT_NAME} =~ m/([^\/\\]*.pl)\?*.*$/;
+    $script = $1;
+} else {
+    $0 =~ tr/\\/\//;
+    $pos = rindex $0, '/';
+    $script = substr( $0, $pos + 1 );
+}
+
 
 $locale = LedgerSMB::Locale->get_handle( ${LedgerSMB::Sysconfig::language} )
   or $form->error( __FILE__ . ':' . __LINE__ . ": Locale not loaded: $!\n" );
 
 
-
 # we use $script for the language module
 $form->{script} = $script;
 
@@ -200,11 +208,11 @@ sub check_password {
         #check for valid session
         if ( !LedgerSMB::Auth::session_check( $cookie{${LedgerSMB::Sysconfig::cookie_name}}, $form ) ) {
             &getpassword(1);
-            exit;
+            return;
         }
     }
     else {
-        exit;
+        return;
     }
 }
 
