@@ -21,8 +21,6 @@ package LedgerSMB::Scripts::recon;
 use LedgerSMB::Template;
 use LedgerSMB::DBObject::Reconciliation;
 use LedgerSMB::Setting;
-use Try::Tiny;
-
 use Data::Dumper;
 use strict;
 
@@ -407,11 +405,14 @@ Displays the new report screen.
 =cut
 sub new_report {
     my ($request) = @_;
-    if ($request->{total} && $request->{total} =~ m|[/-]|){
+
+    # Trap user error: dates accidentally entered in the amount field    
+    if ($request->{total} && $request->{total} =~ m|\d[/-]|){
         $request->error($request->{_locale}->text(
            'Invalid statement balance.  Hint: Try entering a number'
         ));
     }
+
     $request->{total} = $request->parse_amount(amount => $request->{total});
     my $template;
     my $return;
