@@ -1,4 +1,3 @@
-
 =head1 NAME
 
 LedgerSMB::Scripts::setup
@@ -19,6 +18,7 @@ management tasks.
 #
 package LedgerSMB::Scripts::setup;
 
+use Locale::Country;
 use LedgerSMB::Auth;
 use LedgerSMB::Database;
 use strict;
@@ -262,7 +262,6 @@ sub run_backup {
             print $data;
         }
         unlink $backupfile;
-        exit;
     } else {
         $request->error($request->{_locale}->text("Don't know what to do with backup"));
     }
@@ -346,6 +345,34 @@ sub migrate_sl{
 
 }
 
+=item _get_linked_accounts
+
+Returns an array of hashrefs with keys ('id', 'accno', 'desc') identifying
+the accounts.
+
+Assumes a connected database.
+
+=cut
+
+sub _get_linked_accounts {
+    my ($request, $link) = @_;
+    my @accounts;
+
+    my $sth = $request->{dbh}->prepare("select id, accno, description
+                                          from chart
+                                         where link = '$link'");
+    $sth->execute();
+    while (my $row = $sth->fetchrow_hashref('NAME_lc')) {
+        push @accounts, { accno => $row->{accno},
+                          desc => "$row->{accno} - $row->{description}",
+                          id => $row->{id}
+        };
+    }
+
+    return @accounts;
+}
+
+
 =item upgrade 
 
 Beginning of the upgrade from 1.2 logic
@@ -431,6 +458,22 @@ sub upgrade{
              _failed_check($request, $check, $sth);
         }
     }
+
+    @{$request->{ar_accounts}} = _get_linked_accounts($request, "AR");
+    @{$request->{ap_accounts}} = _get_linked_accounts($request, "AP");
+    unshift @{$request->{ar_accounts}}, {};
+    unshift @{$request->{ap_accounts}}, {};
+
+    @{$request->{countries}} = ();
+    foreach my $iso2 (all_country_codes()) {
+        push @{$request->{countries}}, { code    => uc($iso2),
+                                         country => code2country($iso2) };
+    }
+    @{$request->{countries}} =
+        sort { $a->{country} cmp $b->{country} } @{$request->{countries}};
+    unshift @{$request->{countries}}, {};
+
+
     my $template = LedgerSMB::Template->new(
             path => 'UI/setup',
             template => 'upgrade_info',
@@ -764,7 +807,7 @@ sub save_user {
                 format => 'HTML',
         );
         $template->render($request);
-        exit;        
+        return;
     }
     if ($request->{perms} == 1){
          for my $role (
@@ -786,13 +829,9 @@ sub save_user {
         $request->error($request->{_locale}->text('No Permissions Assigned'));
    }
    $request->{dbh}->commit;
+
+   rebuild_modules($request);
    
-    my $template = LedgerSMB::Template->new(
-            path => 'UI/setup',
-            template => 'complete',
-	    format => 'HTML',
-    );
-    $template->render($request);
 }
 
 =item run_upgrade
