@@ -8,9 +8,9 @@ SELECT *
   FROM parts 
  WHERE ($1 IS NULL OR (partnumber like $1 || '%'))
        AND ($2 IS NULL 
-            OR (to_tsvector(get_default_lang()::name, description) 
+            OR (description
                 @@
-                plainto_tsquery(get_default_lang()::name, $2)))
+                plainto_tsquery(get_default_lang()::regconfig, $2)))
        AND not obsolete
 ORDER BY partnumber;
 $$ LANGUAGE SQL;
