@@ -1,6 +1,34 @@
 #!/bin/sh
 
-# Script to explain the steps to take when installing LedgerSMB
+# Copyright (c) 2012, The LedgerSMB Core Team
+# All rights reserved. 
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are met: 
+#
+# Redistributions of source code must retain the above copyright notice, this
+# list of conditions and the following disclaimer. 
+#
+# Redistributions in binary form must reproduce the above copyright notice, this
+# list of conditions and the following disclaimer in the documentation and/or
+# other materials provided with the distribution. 
+#
+# THIS SOFTWARE IS PROVIDED BY THE LEDGERSMB CORE TEAM AND CONTRIBUTORS "AS
+# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+# DISCLAIMED. IN NO EVENT SHALL LEDGERSMB CORE TEAM OR CONTRIBUTORS BE
+# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+# POSSIBILITY OF SUCH DAMAGE.
+#
+# This is the prepare-company-database.sh which serves as a command line tool
+# for creating LedgerSMB databases and also as a reference implementation to 
+# demonstrate how databases are created.
+#
 
 # Default variable values section
 
@@ -92,6 +120,15 @@ ERROR:  language \"plpgsql\" already exists|\
 )/d" -
 }
 
+# Test getopt version. This script use the GNU 'getopt' version.
+getopt -T > /dev/null
+if [ $? -eq 0 ]; then
+    # Original getopt is available
+    echo "This script need the GNU enhanced getopt to work"
+    echo "Use prepare-company-database.pl on your platform"
+    exit 0
+fi
+
 # Am I root?
 if ! test `whoami` = "root"
 then
@@ -216,7 +253,7 @@ export PGPASSWORD
 # Load the required PostgreSQL contribs, if a directory was specified
 if ! test "x$pgsql_contrib_dir" = "xignored"
 then
-  for contrib in tsearch2.sql pg_trgm.sql tablefunc.sql
+  for contrib in tsearch2.sql tablefunc.sql
   do
     cat $pgsql_contrib_dir/$contrib | $psql_cmd 2>&1 | unchatter
   done
